==> haskell-unix-time-0.4.7-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unix-time
version:              0.4.7
visibility:           public
id:                   unix-time-0.4.7-CjmL2e4q2WACVfAnkaMvLN
key:                  unix-time-0.4.7-CjmL2e4q2WACVfAnkaMvLN
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Unix time parser/formatter and utilities
description:          Fast parser\/formatter\/utilities for Unix time
category:             Data
abi:                  03a01e17f04433ac81cee5bd8efca8e7
exposed:              True
exposed-modules:      Data.UnixTime
hidden-modules:
    Data.UnixTime.Conv Data.UnixTime.Diff Data.UnixTime.Types
    Data.UnixTime.Sys

import-dirs:          /usr/lib/ghc-8.10.2/site-local/unix-time-0.4.7
library-dirs:         /usr/lib/ghc-8.10.2/site-local/unix-time-0.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/unix-time-0.4.7
hs-libraries:         HSunix-time-0.4.7-CjmL2e4q2WACVfAnkaMvLN
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.10.0
    old-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK

haddock-interfaces:   /usr/share/doc/haskell-unix-time/html/unix-time.haddock
haddock-html:         /usr/share/doc/haskell-unix-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-time-0.4.7-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unix-time
version:              0.4.7
visibility:           public
id:                   unix-time-0.4.7-93AM3cs00Q44zUxQ0vHAF2
key:                  unix-time-0.4.7-93AM3cs00Q44zUxQ0vHAF2
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Unix time parser/formatter and utilities
description:          Fast parser\/formatter\/utilities for Unix time
category:             Data
abi:                  21217d0f2e06dab79894fbab5a3474e5
exposed:              True
exposed-modules:      Data.UnixTime
hidden-modules:
    Data.UnixTime.Conv Data.UnixTime.Diff Data.UnixTime.Types
    Data.UnixTime.Sys

import-dirs:          /usr/lib/ghc-8.10.2/site-local/unix-time-0.4.7
library-dirs:         /usr/lib/ghc-8.10.2/site-local/unix-time-0.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/unix-time-0.4.7
hs-libraries:         HSunix-time-0.4.7-93AM3cs00Q44zUxQ0vHAF2
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.10.0
    old-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK

haddock-interfaces:   /usr/share/doc/haskell-unix-time/html/unix-time.haddock
haddock-html:         /usr/share/doc/haskell-unix-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
